# coding: utf-8

"""
    Emby Server REST API (BETA)
"""

import pprint
import re  # noqa: F401

import six

class CodecProfile(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'type': 'CodecType',
        'conditions': 'list[ProfileCondition]',
        'apply_conditions': 'list[ProfileCondition]',
        'codec': 'str',
        'container': 'str'
    }

    attribute_map = {
        'type': 'Type',
        'conditions': 'Conditions',
        'apply_conditions': 'ApplyConditions',
        'codec': 'Codec',
        'container': 'Container'
    }

    def __init__(self, type=None, conditions=None, apply_conditions=None, codec=None, container=None):  # noqa: E501
        """CodecProfile - a model defined in Swagger"""  # noqa: E501
        self._type = None
        self._conditions = None
        self._apply_conditions = None
        self._codec = None
        self._container = None
        self.discriminator = None
        if type is not None:
            self.type = type
        if conditions is not None:
            self.conditions = conditions
        if apply_conditions is not None:
            self.apply_conditions = apply_conditions
        if codec is not None:
            self.codec = codec
        if container is not None:
            self.container = container

    @property
    def type(self):
        """Gets the type of this CodecProfile.  # noqa: E501


        :return: The type of this CodecProfile.  # noqa: E501
        :rtype: CodecType
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this CodecProfile.


        :param type: The type of this CodecProfile.  # noqa: E501
        :type: CodecType
        """

        self._type = type

    @property
    def conditions(self):
        """Gets the conditions of this CodecProfile.  # noqa: E501


        :return: The conditions of this CodecProfile.  # noqa: E501
        :rtype: list[ProfileCondition]
        """
        return self._conditions

    @conditions.setter
    def conditions(self, conditions):
        """Sets the conditions of this CodecProfile.


        :param conditions: The conditions of this CodecProfile.  # noqa: E501
        :type: list[ProfileCondition]
        """

        self._conditions = conditions

    @property
    def apply_conditions(self):
        """Gets the apply_conditions of this CodecProfile.  # noqa: E501


        :return: The apply_conditions of this CodecProfile.  # noqa: E501
        :rtype: list[ProfileCondition]
        """
        return self._apply_conditions

    @apply_conditions.setter
    def apply_conditions(self, apply_conditions):
        """Sets the apply_conditions of this CodecProfile.


        :param apply_conditions: The apply_conditions of this CodecProfile.  # noqa: E501
        :type: list[ProfileCondition]
        """

        self._apply_conditions = apply_conditions

    @property
    def codec(self):
        """Gets the codec of this CodecProfile.  # noqa: E501


        :return: The codec of this CodecProfile.  # noqa: E501
        :rtype: str
        """
        return self._codec

    @codec.setter
    def codec(self, codec):
        """Sets the codec of this CodecProfile.


        :param codec: The codec of this CodecProfile.  # noqa: E501
        :type: str
        """

        self._codec = codec

    @property
    def container(self):
        """Gets the container of this CodecProfile.  # noqa: E501


        :return: The container of this CodecProfile.  # noqa: E501
        :rtype: str
        """
        return self._container

    @container.setter
    def container(self, container):
        """Sets the container of this CodecProfile.


        :param container: The container of this CodecProfile.  # noqa: E501
        :type: str
        """

        self._container = container

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(CodecProfile, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CodecProfile):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
