# coding: utf-8

"""
    Emby Server REST API (BETA)
"""

import pprint
import re  # noqa: F401

import six

class MBBackupApiAllBackupsInfo(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'full_backup_info': 'MBBackupBackupInfo',
        'light_backups': 'list[MBBackupBackupInfo]'
    }

    attribute_map = {
        'full_backup_info': 'FullBackupInfo',
        'light_backups': 'LightBackups'
    }

    def __init__(self, full_backup_info=None, light_backups=None):  # noqa: E501
        """MBBackupApiAllBackupsInfo - a model defined in Swagger"""  # noqa: E501
        self._full_backup_info = None
        self._light_backups = None
        self.discriminator = None
        if full_backup_info is not None:
            self.full_backup_info = full_backup_info
        if light_backups is not None:
            self.light_backups = light_backups

    @property
    def full_backup_info(self):
        """Gets the full_backup_info of this MBBackupApiAllBackupsInfo.  # noqa: E501


        :return: The full_backup_info of this MBBackupApiAllBackupsInfo.  # noqa: E501
        :rtype: MBBackupBackupInfo
        """
        return self._full_backup_info

    @full_backup_info.setter
    def full_backup_info(self, full_backup_info):
        """Sets the full_backup_info of this MBBackupApiAllBackupsInfo.


        :param full_backup_info: The full_backup_info of this MBBackupApiAllBackupsInfo.  # noqa: E501
        :type: MBBackupBackupInfo
        """

        self._full_backup_info = full_backup_info

    @property
    def light_backups(self):
        """Gets the light_backups of this MBBackupApiAllBackupsInfo.  # noqa: E501


        :return: The light_backups of this MBBackupApiAllBackupsInfo.  # noqa: E501
        :rtype: list[MBBackupBackupInfo]
        """
        return self._light_backups

    @light_backups.setter
    def light_backups(self, light_backups):
        """Sets the light_backups of this MBBackupApiAllBackupsInfo.


        :param light_backups: The light_backups of this MBBackupApiAllBackupsInfo.  # noqa: E501
        :type: list[MBBackupBackupInfo]
        """

        self._light_backups = light_backups

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(MBBackupApiAllBackupsInfo, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, MBBackupApiAllBackupsInfo):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
