# coding: utf-8

"""
    Emby Server REST API (BETA)
"""

import pprint
import re  # noqa: F401

import six

class PackageVersionInfo(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'name': 'str',
        'guid': 'str',
        'version_str': 'str',
        'classification': 'PackageVersionClass',
        'description': 'str',
        'required_version_str': 'str',
        'source_url': 'str',
        'checksum': 'str',
        'target_filename': 'str',
        'info_url': 'str',
        'runtimes': 'str',
        'timestamp': 'datetime'
    }

    attribute_map = {
        'name': 'name',
        'guid': 'guid',
        'version_str': 'versionStr',
        'classification': 'classification',
        'description': 'description',
        'required_version_str': 'requiredVersionStr',
        'source_url': 'sourceUrl',
        'checksum': 'checksum',
        'target_filename': 'targetFilename',
        'info_url': 'infoUrl',
        'runtimes': 'runtimes',
        'timestamp': 'timestamp'
    }

    def __init__(self, name=None, guid=None, version_str=None, classification=None, description=None, required_version_str=None, source_url=None, checksum=None, target_filename=None, info_url=None, runtimes=None, timestamp=None):  # noqa: E501
        """PackageVersionInfo - a model defined in Swagger"""  # noqa: E501
        self._name = None
        self._guid = None
        self._version_str = None
        self._classification = None
        self._description = None
        self._required_version_str = None
        self._source_url = None
        self._checksum = None
        self._target_filename = None
        self._info_url = None
        self._runtimes = None
        self._timestamp = None
        self.discriminator = None
        if name is not None:
            self.name = name
        if guid is not None:
            self.guid = guid
        if version_str is not None:
            self.version_str = version_str
        if classification is not None:
            self.classification = classification
        if description is not None:
            self.description = description
        if required_version_str is not None:
            self.required_version_str = required_version_str
        if source_url is not None:
            self.source_url = source_url
        if checksum is not None:
            self.checksum = checksum
        if target_filename is not None:
            self.target_filename = target_filename
        if info_url is not None:
            self.info_url = info_url
        if runtimes is not None:
            self.runtimes = runtimes
        if timestamp is not None:
            self.timestamp = timestamp

    @property
    def name(self):
        """Gets the name of this PackageVersionInfo.  # noqa: E501

        The name.  # noqa: E501

        :return: The name of this PackageVersionInfo.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this PackageVersionInfo.

        The name.  # noqa: E501

        :param name: The name of this PackageVersionInfo.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def guid(self):
        """Gets the guid of this PackageVersionInfo.  # noqa: E501

        The guid.  # noqa: E501

        :return: The guid of this PackageVersionInfo.  # noqa: E501
        :rtype: str
        """
        return self._guid

    @guid.setter
    def guid(self, guid):
        """Sets the guid of this PackageVersionInfo.

        The guid.  # noqa: E501

        :param guid: The guid of this PackageVersionInfo.  # noqa: E501
        :type: str
        """

        self._guid = guid

    @property
    def version_str(self):
        """Gets the version_str of this PackageVersionInfo.  # noqa: E501

        The version STR.  # noqa: E501

        :return: The version_str of this PackageVersionInfo.  # noqa: E501
        :rtype: str
        """
        return self._version_str

    @version_str.setter
    def version_str(self, version_str):
        """Sets the version_str of this PackageVersionInfo.

        The version STR.  # noqa: E501

        :param version_str: The version_str of this PackageVersionInfo.  # noqa: E501
        :type: str
        """

        self._version_str = version_str

    @property
    def classification(self):
        """Gets the classification of this PackageVersionInfo.  # noqa: E501


        :return: The classification of this PackageVersionInfo.  # noqa: E501
        :rtype: PackageVersionClass
        """
        return self._classification

    @classification.setter
    def classification(self, classification):
        """Sets the classification of this PackageVersionInfo.


        :param classification: The classification of this PackageVersionInfo.  # noqa: E501
        :type: PackageVersionClass
        """

        self._classification = classification

    @property
    def description(self):
        """Gets the description of this PackageVersionInfo.  # noqa: E501

        The description.  # noqa: E501

        :return: The description of this PackageVersionInfo.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this PackageVersionInfo.

        The description.  # noqa: E501

        :param description: The description of this PackageVersionInfo.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def required_version_str(self):
        """Gets the required_version_str of this PackageVersionInfo.  # noqa: E501

        The required version STR.  # noqa: E501

        :return: The required_version_str of this PackageVersionInfo.  # noqa: E501
        :rtype: str
        """
        return self._required_version_str

    @required_version_str.setter
    def required_version_str(self, required_version_str):
        """Sets the required_version_str of this PackageVersionInfo.

        The required version STR.  # noqa: E501

        :param required_version_str: The required_version_str of this PackageVersionInfo.  # noqa: E501
        :type: str
        """

        self._required_version_str = required_version_str

    @property
    def source_url(self):
        """Gets the source_url of this PackageVersionInfo.  # noqa: E501

        The source URL.  # noqa: E501

        :return: The source_url of this PackageVersionInfo.  # noqa: E501
        :rtype: str
        """
        return self._source_url

    @source_url.setter
    def source_url(self, source_url):
        """Sets the source_url of this PackageVersionInfo.

        The source URL.  # noqa: E501

        :param source_url: The source_url of this PackageVersionInfo.  # noqa: E501
        :type: str
        """

        self._source_url = source_url

    @property
    def checksum(self):
        """Gets the checksum of this PackageVersionInfo.  # noqa: E501

        The source URL.  # noqa: E501

        :return: The checksum of this PackageVersionInfo.  # noqa: E501
        :rtype: str
        """
        return self._checksum

    @checksum.setter
    def checksum(self, checksum):
        """Sets the checksum of this PackageVersionInfo.

        The source URL.  # noqa: E501

        :param checksum: The checksum of this PackageVersionInfo.  # noqa: E501
        :type: str
        """

        self._checksum = checksum

    @property
    def target_filename(self):
        """Gets the target_filename of this PackageVersionInfo.  # noqa: E501

        The target filename.  # noqa: E501

        :return: The target_filename of this PackageVersionInfo.  # noqa: E501
        :rtype: str
        """
        return self._target_filename

    @target_filename.setter
    def target_filename(self, target_filename):
        """Sets the target_filename of this PackageVersionInfo.

        The target filename.  # noqa: E501

        :param target_filename: The target_filename of this PackageVersionInfo.  # noqa: E501
        :type: str
        """

        self._target_filename = target_filename

    @property
    def info_url(self):
        """Gets the info_url of this PackageVersionInfo.  # noqa: E501


        :return: The info_url of this PackageVersionInfo.  # noqa: E501
        :rtype: str
        """
        return self._info_url

    @info_url.setter
    def info_url(self, info_url):
        """Sets the info_url of this PackageVersionInfo.


        :param info_url: The info_url of this PackageVersionInfo.  # noqa: E501
        :type: str
        """

        self._info_url = info_url

    @property
    def runtimes(self):
        """Gets the runtimes of this PackageVersionInfo.  # noqa: E501


        :return: The runtimes of this PackageVersionInfo.  # noqa: E501
        :rtype: str
        """
        return self._runtimes

    @runtimes.setter
    def runtimes(self, runtimes):
        """Sets the runtimes of this PackageVersionInfo.


        :param runtimes: The runtimes of this PackageVersionInfo.  # noqa: E501
        :type: str
        """

        self._runtimes = runtimes

    @property
    def timestamp(self):
        """Gets the timestamp of this PackageVersionInfo.  # noqa: E501


        :return: The timestamp of this PackageVersionInfo.  # noqa: E501
        :rtype: datetime
        """
        return self._timestamp

    @timestamp.setter
    def timestamp(self, timestamp):
        """Sets the timestamp of this PackageVersionInfo.


        :param timestamp: The timestamp of this PackageVersionInfo.  # noqa: E501
        :type: datetime
        """

        self._timestamp = timestamp

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(PackageVersionInfo, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PackageVersionInfo):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
