# coding: utf-8

"""
    Emby Server REST API (BETA)
"""

import pprint
import re  # noqa: F401

import six

class DevicesContentUploadHistory(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'device_id': 'str',
        'files_uploaded': 'list[DevicesLocalFileInfo]'
    }

    attribute_map = {
        'device_id': 'DeviceId',
        'files_uploaded': 'FilesUploaded'
    }

    def __init__(self, device_id=None, files_uploaded=None):  # noqa: E501
        """DevicesContentUploadHistory - a model defined in Swagger"""  # noqa: E501
        self._device_id = None
        self._files_uploaded = None
        self.discriminator = None
        if device_id is not None:
            self.device_id = device_id
        if files_uploaded is not None:
            self.files_uploaded = files_uploaded

    @property
    def device_id(self):
        """Gets the device_id of this DevicesContentUploadHistory.  # noqa: E501


        :return: The device_id of this DevicesContentUploadHistory.  # noqa: E501
        :rtype: str
        """
        return self._device_id

    @device_id.setter
    def device_id(self, device_id):
        """Sets the device_id of this DevicesContentUploadHistory.


        :param device_id: The device_id of this DevicesContentUploadHistory.  # noqa: E501
        :type: str
        """

        self._device_id = device_id

    @property
    def files_uploaded(self):
        """Gets the files_uploaded of this DevicesContentUploadHistory.  # noqa: E501


        :return: The files_uploaded of this DevicesContentUploadHistory.  # noqa: E501
        :rtype: list[DevicesLocalFileInfo]
        """
        return self._files_uploaded

    @files_uploaded.setter
    def files_uploaded(self, files_uploaded):
        """Sets the files_uploaded of this DevicesContentUploadHistory.


        :param files_uploaded: The files_uploaded of this DevicesContentUploadHistory.  # noqa: E501
        :type: list[DevicesLocalFileInfo]
        """

        self._files_uploaded = files_uploaded

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(DevicesContentUploadHistory, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DevicesContentUploadHistory):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
