# coding: utf-8

"""
    Emby Server REST API (BETA)
"""

import pprint
import re  # noqa: F401

import six

class PlaylistsAddToPlaylistInfo(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'item_count': 'int',
        'contains_duplicates': 'bool'
    }

    attribute_map = {
        'item_count': 'ItemCount',
        'contains_duplicates': 'ContainsDuplicates'
    }

    def __init__(self, item_count=None, contains_duplicates=None):  # noqa: E501
        """PlaylistsAddToPlaylistInfo - a model defined in Swagger"""  # noqa: E501
        self._item_count = None
        self._contains_duplicates = None
        self.discriminator = None
        if item_count is not None:
            self.item_count = item_count
        if contains_duplicates is not None:
            self.contains_duplicates = contains_duplicates

    @property
    def item_count(self):
        """Gets the item_count of this PlaylistsAddToPlaylistInfo.  # noqa: E501


        :return: The item_count of this PlaylistsAddToPlaylistInfo.  # noqa: E501
        :rtype: int
        """
        return self._item_count

    @item_count.setter
    def item_count(self, item_count):
        """Sets the item_count of this PlaylistsAddToPlaylistInfo.


        :param item_count: The item_count of this PlaylistsAddToPlaylistInfo.  # noqa: E501
        :type: int
        """

        self._item_count = item_count

    @property
    def contains_duplicates(self):
        """Gets the contains_duplicates of this PlaylistsAddToPlaylistInfo.  # noqa: E501


        :return: The contains_duplicates of this PlaylistsAddToPlaylistInfo.  # noqa: E501
        :rtype: bool
        """
        return self._contains_duplicates

    @contains_duplicates.setter
    def contains_duplicates(self, contains_duplicates):
        """Sets the contains_duplicates of this PlaylistsAddToPlaylistInfo.


        :param contains_duplicates: The contains_duplicates of this PlaylistsAddToPlaylistInfo.  # noqa: E501
        :type: bool
        """

        self._contains_duplicates = contains_duplicates

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(PlaylistsAddToPlaylistInfo, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PlaylistsAddToPlaylistInfo):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
