from __future__ import absolute_import

# flake8: noqa

# import apis into api package
from emby_client.api.activity_log_service_api import ActivityLogServiceApi
from emby_client.api.artists_service_api import ArtistsServiceApi
from emby_client.api.audio_service_api import AudioServiceApi
from emby_client.api.backup_api_api import BackupApiApi
from emby_client.api.bif_service_api import BifServiceApi
from emby_client.api.branding_service_api import BrandingServiceApi
from emby_client.api.channel_service_api import ChannelServiceApi
from emby_client.api.codec_parameter_service_api import CodecParameterServiceApi
from emby_client.api.collection_service_api import CollectionServiceApi
from emby_client.api.configuration_service_api import ConfigurationServiceApi
from emby_client.api.connect_service_api import ConnectServiceApi
from emby_client.api.device_service_api import DeviceServiceApi
from emby_client.api.display_preferences_service_api import DisplayPreferencesServiceApi
from emby_client.api.dlna_server_service_api import DlnaServerServiceApi
from emby_client.api.dlna_service_api import DlnaServiceApi
from emby_client.api.dynamic_hls_service_api import DynamicHlsServiceApi
from emby_client.api.encoding_info_service_api import EncodingInfoServiceApi
from emby_client.api.environment_service_api import EnvironmentServiceApi
from emby_client.api.feature_service_api import FeatureServiceApi
from emby_client.api.ffmpeg_options_service_api import FfmpegOptionsServiceApi
from emby_client.api.game_genres_service_api import GameGenresServiceApi
from emby_client.api.generic_ui_api_service_api import GenericUIApiServiceApi
from emby_client.api.genres_service_api import GenresServiceApi
from emby_client.api.hls_segment_service_api import HlsSegmentServiceApi
from emby_client.api.image_service_api import ImageServiceApi
from emby_client.api.instant_mix_service_api import InstantMixServiceApi
from emby_client.api.item_lookup_service_api import ItemLookupServiceApi
from emby_client.api.item_refresh_service_api import ItemRefreshServiceApi
from emby_client.api.item_update_service_api import ItemUpdateServiceApi
from emby_client.api.items_service_api import ItemsServiceApi
from emby_client.api.library_service_api import LibraryServiceApi
from emby_client.api.library_structure_service_api import LibraryStructureServiceApi
from emby_client.api.live_stream_service_api import LiveStreamServiceApi
from emby_client.api.live_tv_service_api import LiveTvServiceApi
from emby_client.api.localization_service_api import LocalizationServiceApi
from emby_client.api.media_info_service_api import MediaInfoServiceApi
from emby_client.api.movies_service_api import MoviesServiceApi
from emby_client.api.music_genres_service_api import MusicGenresServiceApi
from emby_client.api.notifications_service_api import NotificationsServiceApi
from emby_client.api.official_rating_service_api import OfficialRatingServiceApi
from emby_client.api.open_api_service_api import OpenApiServiceApi
from emby_client.api.package_service_api import PackageServiceApi
from emby_client.api.persons_service_api import PersonsServiceApi
from emby_client.api.playlist_service_api import PlaylistServiceApi
from emby_client.api.playstate_service_api import PlaystateServiceApi
from emby_client.api.plugin_service_api import PluginServiceApi
from emby_client.api.remote_image_service_api import RemoteImageServiceApi
from emby_client.api.scheduled_task_service_api import ScheduledTaskServiceApi
from emby_client.api.sessions_service_api import SessionsServiceApi
from emby_client.api.studios_service_api import StudiosServiceApi
from emby_client.api.subtitle_options_service_api import SubtitleOptionsServiceApi
from emby_client.api.subtitle_service_api import SubtitleServiceApi
from emby_client.api.suggestions_service_api import SuggestionsServiceApi
from emby_client.api.sync_service_api import SyncServiceApi
from emby_client.api.system_service_api import SystemServiceApi
from emby_client.api.tag_service_api import TagServiceApi
from emby_client.api.tone_map_options_service_api import ToneMapOptionsServiceApi
from emby_client.api.trailers_service_api import TrailersServiceApi
from emby_client.api.tv_shows_service_api import TvShowsServiceApi
from emby_client.api.universal_audio_service_api import UniversalAudioServiceApi
from emby_client.api.user_library_service_api import UserLibraryServiceApi
from emby_client.api.user_notifications_service_api import UserNotificationsServiceApi
from emby_client.api.user_service_api import UserServiceApi
from emby_client.api.user_views_service_api import UserViewsServiceApi
from emby_client.api.video_hls_service_api import VideoHlsServiceApi
from emby_client.api.video_service_api import VideoServiceApi
from emby_client.api.videos_service_api import VideosServiceApi
from emby_client.api.web_app_service_api import WebAppServiceApi
